marktools.detach_lilypond_command_marks_attached_to_component
=============================================================

.. autofunction:: abjad.tools.marktools.detach_lilypond_command_marks_attached_to_component.detach_lilypond_command_marks_attached_to_component
